[9/9] sched/balancing: Rename run_rebalance_domains() => sched_balance_softirq()

Message ID 20240304094831.3639338-10-mingo@kernel.org
State New
Headers
Series sched/balancing: Misc updates & cleanups |

Commit Message

Ingo Molnar March 4, 2024, 9:48 a.m. UTC
  run_rebalance_domains() is a misnomer, as it doesn't only
run rebalance_domains(), but since the introduction of the
NOHZ code it also runs nohz_idle_balance().

Rename it to sched_balance_softirq(), reflecting its more
generic purpose and that it's a softirq handler.

Signed-off-by: Ingo Molnar <mingo@kernel.org>
Cc: Peter Zijlstra <peterz@infradead.org>
Cc: Vincent Guittot <vincent.guittot@linaro.org>
Cc: Dietmar Eggemann <dietmar.eggemann@arm.com>
Cc: Linus Torvalds <torvalds@linux-foundation.org>
Cc: Valentin Schneider <vschneid@redhat.com>
---
 Documentation/scheduler/sched-domains.rst                    | 2 +-
 Documentation/translations/zh_CN/scheduler/sched-domains.rst | 2 +-
 kernel/sched/fair.c                                          | 6 +++---
 3 files changed, 5 insertions(+), 5 deletions(-)
  

Patch

diff --git a/Documentation/scheduler/sched-domains.rst b/Documentation/scheduler/sched-domains.rst
index e57ad28301bd..6577b068f921 100644
--- a/Documentation/scheduler/sched-domains.rst
+++ b/Documentation/scheduler/sched-domains.rst
@@ -34,7 +34,7 @@  out of balance are tasks moved between groups.
 In kernel/sched/core.c, trigger_load_balance() is run periodically on each CPU
 through scheduler_tick(). It raises a softirq after the next regularly scheduled
 rebalancing event for the current runqueue has arrived. The actual load
-balancing workhorse, run_rebalance_domains()->rebalance_domains(), is then run
+balancing workhorse, sched_balance_softirq()->rebalance_domains(), is then run
 in softirq context (SCHED_SOFTIRQ).
 
 The latter function takes two arguments: the runqueue of current CPU and whether
diff --git a/Documentation/translations/zh_CN/scheduler/sched-domains.rst b/Documentation/translations/zh_CN/scheduler/sched-domains.rst
index e814d4c01141..fbc326668e37 100644
--- a/Documentation/translations/zh_CN/scheduler/sched-domains.rst
+++ b/Documentation/translations/zh_CN/scheduler/sched-domains.rst
@@ -36,7 +36,7 @@  CPU共享。任意两个组的CPU掩码的交集不一定为空,如果是这
 
 在kernel/sched/core.c中,trigger_load_balance()在每个CPU上通过scheduler_tick()
 周期执行。在当前运行队列下一个定期调度再平衡事件到达后,它引发一个软中断。负载均衡真正
-的工作由run_rebalance_domains()->rebalance_domains()完成,在软中断上下文中执行
+的工作由sched_balance_softirq()->rebalance_domains()完成,在软中断上下文中执行
 (SCHED_SOFTIRQ)。
 
 后一个函数有两个入参:当前CPU的运行队列、它在scheduler_tick()调用时是否空闲。函数会从
diff --git a/kernel/sched/fair.c b/kernel/sched/fair.c
index 0eb2cafa1509..cdf0dbb9d3e3 100644
--- a/kernel/sched/fair.c
+++ b/kernel/sched/fair.c
@@ -12408,7 +12408,7 @@  static int newidle_balance(struct rq *this_rq, struct rq_flags *rf)
 }
 
 /*
  * The run_rebalance_domains() softirq handler is triggered via SCHED_SOFTIRQ
  * from two places:
  *
  *  - the scheduler_tick(),
@@ -12416,7 +12416,7 @@  static int newidle_balance(struct rq *this_rq, struct rq_flags *rf)
  *  - from the SMP cross-call function nohz_csd_func(),
  *    used by NOHZ idle balancing (with NOHZ_BALANCE_KICK set).
  */
-static __latent_entropy void run_rebalance_domains(struct softirq_action *h)
+static __latent_entropy void sched_balance_softirq(struct softirq_action *h)
 {
 	struct rq *this_rq = this_rq();
 	enum cpu_idle_type idle = this_rq->idle_balance;
@@ -13217,7 +13217,7 @@  __init void init_sched_fair_class(void)
 #endif
 	}
 
-	open_softirq(SCHED_SOFTIRQ, run_rebalance_domains);
+	open_softirq(SCHED_SOFTIRQ, sched_balance_softirq);
 
 #ifdef CONFIG_NO_HZ_COMMON
 	nohz.next_balance = jiffies;
@@ -12408,7 +12408,7 @@  static int newidle_balance(struct rq *this_rq, struct rq_flags *rf)
 
 /*
- * The run_rebalance_domains() softirq handler is triggered via SCHED_SOFTIRQ
+ * The sched_balance_softirq() softirq handler is triggered via SCHED_SOFTIRQ
  * from two places:
  *